@@ -1,16 +1,16 @@
 package Email::Sender::Success;
 {
-  $Email::Sender::Success::VERSION = '0.120000'; # TRIAL
+  $Email::Sender::Success::VERSION = '1.300000'; # TRIAL
 }
-use Moose;
+use Moo;
 # ABSTRACT: the result of successfully sending mail
 
 
-__PACKAGE__->meta->make_immutable;
-no Moose;
+no Moo;
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -19,7 +19,7 @@ Email::Sender::Success - the result of successfully sending mail
 
 =head1 VERSION
 
-version 0.120000
+version 1.300000
 
 =head1 DESCRIPTION
 
@@ -32,10 +32,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo Signes.
+This software is copyright (c) 2013 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
