@@ -1,9 +1,10 @@
 package Email::Sender::Success::Partial;
 {
-  $Email::Sender::Success::Partial::VERSION = '0.120000'; # TRIAL
+  $Email::Sender::Success::Partial::VERSION = '1.300000'; # TRIAL
 }
-use Moose;
+use Moo;
 extends 'Email::Sender::Success';
+use MooX::Types::MooseLike::Base qw(InstanceOf);
 # ABSTRACT: a report of partial success when delivering
 
 
@@ -11,15 +12,15 @@ use Email::Sender::Failure::Multi;
 
 has failure => (
   is  => 'ro',
-  isa => 'Email::Sender::Failure::Multi',
+  isa => InstanceOf['Email::Sender::Failure::Multi'],
   required => 1,
 );
 
-__PACKAGE__->meta->make_immutable;
-no Moose;
+no Moo;
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -28,7 +29,7 @@ Email::Sender::Success::Partial - a report of partial success when delivering
 
 =head1 VERSION
 
-version 0.120000
+version 1.300000
 
 =head1 DESCRIPTION
 
@@ -42,10 +43,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo Signes.
+This software is copyright (c) 2013 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
