@@ -1,32 +1,35 @@
 package Email::Sender::Transport::Test;
 {
-  $Email::Sender::Transport::Test::VERSION = '0.120000'; # TRIAL
+  $Email::Sender::Transport::Test::VERSION = '1.300000'; # TRIAL
 }
-use Moose;
+use Moo;
+use MooX::Types::MooseLike::Base qw(ArrayRef Bool);
 # ABSTRACT: deliver mail in memory for testing
 
+with 'Email::Sender::Transport';
 use Email::Sender::Failure::Multi;
 use Email::Sender::Success::Partial;
 
 
-has allow_partial_success => (is => 'ro', isa => 'Bool', default => 0);
+has allow_partial_success => (is => 'ro', isa => Bool, default => sub { 0 });
 
 sub recipient_failure { }
 sub delivery_failure  { }
 
 has deliveries => (
-  isa => 'ArrayRef',
-  traits     => [ 'Array' ],
+  isa => ArrayRef,
   init_arg   => undef,
   default    => sub { [] },
-  handles    => {
-    deliveries       => 'elements',
-    delivery_count   => 'count',
-    clear_deliveries => 'clear',
-    record_delivery  => 'push',
-  },
+  is         => 'ro',
+  reader     => '_deliveries',
 );
 
+sub delivery_count { scalar @{ $_[0]->_deliveries } }
+sub record_delivery { push @{ shift->_deliveries }, @_ }
+sub deliveries { @{ $_[0]->_deliveries } }
+sub shift_deliveries { shift @{ $_[0]->_deliveries } }
+sub clear_deliveries { @{ $_[0]->_deliveries } = () }
+
 sub send_email {
   my ($self, $email, $envelope) = @_;
 
@@ -77,12 +80,11 @@ sub send_email {
   });
 }
 
-with 'Email::Sender::Transport';
-__PACKAGE__->meta->make_immutable;
-no Moose;
+no Moo;
 1;
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -91,7 +93,7 @@ Email::Sender::Transport::Test - deliver mail in memory for testing
 
 =head1 VERSION
 
-version 0.120000
+version 1.300000
 
 =head1 DESCRIPTION
 
@@ -123,7 +125,6 @@ L<Email::Sender::Transport::Failable>.
 =for Pod::Coverage clear_deliveries
 
 This attribute stores an arrayref of all the deliveries made via the transport.
-It can be emptied by calling C<clear_deliveries>.
 
 Each delivery is a hashref, in the following format:
 
@@ -136,16 +137,33 @@ Each delivery is a hashref, in the following format:
 
 Both successful and failed deliveries are stored.
 
+A number of methods related to this attribute are provided:
+
+=over 4
+
+=item *
+
+delivery_count
+
+=item *
+
+clear_deliveries
+
+=item *
+
+shift_deliveries
+
+=back
+
 =head1 AUTHOR
 
 Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Ricardo Signes.
+This software is copyright (c) 2013 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
